==> spring-security-oauth2-autoconfigure-2.2.1.RELEASE-sources.jar: org/springframework/boot/autoconfigure/security/oauth2/resource/JwtAccessTokenConverterRestTemplateCustomizer.java <==
/*
 * Copyright 2012-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.boot.autoconfigure.security.oauth2.resource;

import org.springframework.security.oauth2.provider.token.store.JwtAccessTokenConverter;
import org.springframework.web.client.RestTemplate;

/**
 * Callback for customizing the {@link RestTemplate} that is used to fetch the keys used
 * by {@link JwtAccessTokenConverter}.
 *
 * @author Eddú Meléndez
 * @since 1.5.2
 * @see JwtAccessTokenConverter#setSigningKey(String)
 * @see JwtAccessTokenConverter#setVerifierKey(String)
 * @deprecated Use <a target="_blank" href=
 * "https://docs.spring.io/spring-security/site/docs/current/reference/htmlsingle/#oauth2resourceserver">Spring
 * Security's built-in support</a>
 */
@FunctionalInterface
public interface JwtAccessTokenConverterRestTemplateCustomizer {

	/**
	 * Customize the {@code template} before it is initialized.
	 * @param template the rest template
	 */
	void customize(RestTemplate template);

}

==> spring-security-oauth2-autoconfigure-2.2.2.RELEASE-sources.jar: org/springframework/boot/autoconfigure/security/oauth2/resource/JwtAccessTokenConverterRestTemplateCustomizer.java <==
/*
 * Copyright 2012-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.boot.autoconfigure.security.oauth2.resource;

import org.springframework.security.oauth2.provider.token.store.JwtAccessTokenConverter;
import org.springframework.web.client.RestTemplate;

/**
 * Callback for customizing the {@link RestTemplate} that is used to fetch the
 * keys used by {@link JwtAccessTokenConverter}.
 *
 * @author Eddú Meléndez
 * @since 1.5.2
 * @see JwtAccessTokenConverter#setSigningKey(String)
 * @see JwtAccessTokenConverter#setVerifierKey(String)
 * @deprecated See the <a href=
 *             "https://github.com/spring-projects/spring-security/wiki/OAuth-2.0-Migration-Guide">
 *             OAuth 2.0 Migration Guide</a> for Spring Security 5.
 */
@FunctionalInterface
@Deprecated
public interface JwtAccessTokenConverterRestTemplateCustomizer {

	/**
	 * Customize the {@code template} before it is initialized.
	 * @param template
	 *            the rest template
	 */
	void customize(RestTemplate template);

}
